searchData={"items":[{"type":"module","doc":"Provides a variant system for TailwindCSS in Elixir applications.\n\nThis library allows you to create components with variants, slots, and more,\nsimilar to the JavaScript tailwind-variants library.","title":"TailwindVariants","ref":"TailwindVariants.html"},{"type":"function","doc":"Applies props to a component to generate class names.","title":"TailwindVariants.class_list/2","ref":"TailwindVariants.html#class_list/2"},{"type":"function","doc":"* `component` - A component created with `tv/1`\n* `props` - A map of props to apply to the component","title":"Parameters - TailwindVariants.class_list/2","ref":"TailwindVariants.html#class_list/2-parameters"},{"type":"function","doc":"* A string of class names (if no slots are defined)\n* A map of slot functions (if slots are defined)","title":"Returns - TailwindVariants.class_list/2","ref":"TailwindVariants.html#class_list/2-returns"},{"type":"function","doc":"iex> component = tv(%{base: \"font-medium text-white\"})\n    iex> class_list(component)\n    \"font-medium text-white\"\n\n    iex> component = tv(%{\n    ...>   base: \"font-medium\",\n    ...>   variants: %{\n    ...>     color: %{\n    ...>       primary: \"bg-blue-500\",\n    ...>       secondary: \"bg-purple-500\"\n    ...>     }\n    ...>   }\n    ...> })\n    iex> class_list(component, %{color: \"primary\"})\n    \"font-medium bg-blue-500\"","title":"Examples - TailwindVariants.class_list/2","ref":"TailwindVariants.html#class_list/2-examples"},{"type":"function","doc":"Creates a tailwind-variants component with the given options.","title":"TailwindVariants.tv/1","ref":"TailwindVariants.html#tv/1"},{"type":"function","doc":"* `:base` - Base classes for the component\n* `:slots` - Map of slot names to their classes\n* `:variants` - Map of variant names to their values\n* `:default_variants` - Map of variant names to their default values\n* `:compound_variants` - List of compound variants\n* `:compound_slots` - List of compound slots\n* `:extend` - Another component to extend\n* `:config` - Configuration options","title":"Options - TailwindVariants.tv/1","ref":"TailwindVariants.html#tv/1-options"},{"type":"function","doc":"iex> component = tv(%{base: \"font-medium text-white\"})\n    iex> component.base\n    \"font-medium text-white\"\n\n    iex> component = tv(%{\n    ...>   base: \"font-medium text-white\",\n    ...>   variants: %{\n    ...>     color: %{\n    ...>       primary: \"bg-blue-500\",\n    ...>       secondary: \"bg-purple-500\"\n    ...>     }\n    ...>   }\n    ...> })\n    iex> component.variants.color.primary\n    \"bg-blue-500\"","title":"Examples - TailwindVariants.tv/1","ref":"TailwindVariants.html#tv/1-examples"},{"type":"function","doc":"See `class_list/2`.","title":"TailwindVariants.tw/2","ref":"TailwindVariants.html#tw/2"},{"type":"function","doc":"Returns a map of all available variants and their possible values for a component.\nUseful for generating documentation or validation.","title":"TailwindVariants.variant_options/1","ref":"TailwindVariants.html#variant_options/1"},{"type":"function","doc":"iex> button = tv(%{variants: %{color: %{primary: \"\", secondary: \"\"}}})\n    iex> variant_options(button)\n    %{color: [:primary, :secondary]}","title":"Example - TailwindVariants.variant_options/1","ref":"TailwindVariants.html#variant_options/1-example"},{"type":"module","doc":"","title":"TailwindVariants.Application","ref":"TailwindVariants.Application.html"},{"type":"function","doc":"","title":"TailwindVariants.Application.start/2","ref":"TailwindVariants.Application.html#start/2"},{"type":"module","doc":"Represents a tailwind-variants component.","title":"TailwindVariants.Component","ref":"TailwindVariants.Component.html"},{"type":"module","doc":"Configuration module for TailwindVariants.","title":"TailwindVariants.Config","ref":"TailwindVariants.Config.html"},{"type":"function","doc":"Returns the merged configuration.","title":"TailwindVariants.Config.config/1","ref":"TailwindVariants.Config.html#config/1"},{"type":"module","doc":"Utility functions for manipulating class names.","title":"TailwindVariants.Utils","ref":"TailwindVariants.Utils.html"},{"type":"function","doc":"Convert a map to atom keys.\nWarning that this is not a recursive function and is unsafe and could\nresult in a denial of service attack if you exceed the atom limit.","title":"TailwindVariants.Utils.atomize_keys/1","ref":"TailwindVariants.Utils.html#atomize_keys/1"},{"type":"function","doc":"iex> atomize_keys(%{\"name\" => \"John\", \"age\" => 30})\n    %{name: \"John\", age: 30}\n\n    iex> atomize_keys(%{\"user\" => %{\"name\" => \"John\", \"age\" => 30}})\n    %{user: %{name: \"John\", age: 30}}","title":"Examples - TailwindVariants.Utils.atomize_keys/1","ref":"TailwindVariants.Utils.html#atomize_keys/1-examples"},{"type":"function","doc":"Joins class names, handling nil, empty strings, and nested arrays.","title":"TailwindVariants.Utils.join_class_names/1","ref":"TailwindVariants.Utils.html#join_class_names/1"},{"type":"function","doc":"iex> join_class_names([\"font-bold\", \"text-lg\"])\n    \"font-bold text-lg\"\n\n    iex> join_class_names([\"font-bold\", nil, \"text-lg\"])\n    \"font-bold text-lg\"\n\n    iex> join_class_names([\"font-bold\", [\"text-lg\", \"p-4\"]])\n    \"font-bold text-lg p-4\"","title":"Examples - TailwindVariants.Utils.join_class_names/1","ref":"TailwindVariants.Utils.html#join_class_names/1-examples"},{"type":"function","doc":"Merges class names using tw_merge if enabled in config.","title":"TailwindVariants.Utils.merge_class_names/2","ref":"TailwindVariants.Utils.html#merge_class_names/2"},{"type":"function","doc":"iex> merge_class_names([\"p-4\", \"p-6\"], %{tw_merge: true})\n    \"p-6\"\n\n    iex> merge_class_names([\"p-4\", \"p-6\"], %{tw_merge: false})\n    \"p-4 p-6\"","title":"Examples - TailwindVariants.Utils.merge_class_names/2","ref":"TailwindVariants.Utils.html#merge_class_names/2-examples"},{"type":"function","doc":"Recursively converts all keys in a map to strings.\nHandles nested maps and lists of maps.","title":"TailwindVariants.Utils.stringify_keys/1","ref":"TailwindVariants.Utils.html#stringify_keys/1"},{"type":"function","doc":"iex> stringify_keys(%{name: \"John\", age: 30})\n    %{\"name\" => \"John\", \"age\" => 30}\n\n    iex> stringify_keys(%{user: %{name: \"John\", age: 30}})\n    %{\"user\" => %{\"name\" => \"John\", \"age\" => 30}}","title":"Examples - TailwindVariants.Utils.stringify_keys/1","ref":"TailwindVariants.Utils.html#stringify_keys/1-examples"},{"type":"function","doc":"Convert a string to an atom.","title":"TailwindVariants.Utils.try_existing_atom/1","ref":"TailwindVariants.Utils.html#try_existing_atom/1"},{"type":"extras","doc":"# Tailwind Variants for Elixir\n\nA port of the popular [tailwind-variants](https://www.tailwind-variants.org/) library to Elixir, providing a first-class variant API for TailwindCSS in Elixir applications.","title":"Tailwind Variants for Elixir","ref":"readme.html"},{"type":"extras","doc":"- First-class variant API\n- Slots support\n- Composition support\n- Automatic conflict resolution\n- Compound variants\n- Type-safe variants","title":"Features - Tailwind Variants for Elixir","ref":"readme.html#features"},{"type":"extras","doc":"Add `tailwind_variants` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:tailwind_variants, \"~> 0.1\"},\n    {:tw_merge, \"~> 0.1.1\"} # Required for class merging\n  ]\nend\n```","title":"Installation - Tailwind Variants for Elixir","ref":"readme.html#installation"},{"type":"extras","doc":"","title":"Usage - Tailwind Variants for Elixir","ref":"readme.html#usage"},{"type":"extras","doc":"```elixir\nimport TailwindVariants, only: [tv: 1, class_list: 2]\n\nbutton = tv(%{\n  base: \"font-medium bg-blue-500 text-white rounded-full active:opacity-80\",\n  variants: %{\n    color: %{\n      primary: \"bg-blue-500 text-white\",\n      secondary: \"bg-purple-500 text-white\"\n    },\n    size: %{\n      sm: \"text-sm\",\n      md: \"text-base\",\n      lg: \"px-4 py-3 text-lg\"\n    }\n  },\n  compound_variants: [\n    %{\n      size: [\"sm\", \"md\"],\n      class: \"px-3 py-1\"\n    }\n  ],\n  default_variants: %{\n    size: \"md\",\n    color: \"primary\"\n  }\n})\n\n# Use in Phoenix/LiveView\n \n  Click me\n \n```","title":"Basic Example - Tailwind Variants for Elixir","ref":"readme.html#basic-example"},{"type":"extras","doc":"Slots allows you to separate a component into multiple parts.\n\n```elixir\nimport TailwindVariants, only: [tv: 1, class_list: 2]\n\ncard = tv(%{\n  slots: %{\n    base: \"md:flex bg-slate-100 rounded-xl p-8 md:p-0 dark:bg-gray-900\",\n    avatar: \"w-24 h-24 md:w-48 md:h-auto md:rounded-none rounded-full mx-auto drop-shadow-lg\",\n    wrapper: \"flex-1 pt-6 md:p-8 text-center md:text-left space-y-4\",\n    description: \"text-md font-medium\",\n    info_wrapper: \"font-medium\",\n    name: \"text-sm text-sky-500 dark:text-sky-400\",\n    role: \"text-sm text-slate-700 dark:text-slate-500\"\n  }\n})\n\n# Destructure the slots\n%{base: base, avatar: avatar, wrapper: wrapper, description: description,\n  info_wrapper: info_wrapper, name: name, role: role} = class_list(card, %{})\n\n# Use in Phoenix/LiveView\n \n   \n   \n     \n       \n        \"Tailwind variants allows you to reduce repeated code in your project\n        and make it more readable.\"\n       \n     \n     \n       Zoey Lang \n       Full-stack developer \n     \n   \n \n```","title":"With Slots - Tailwind Variants for Elixir","ref":"readme.html#with-slots"},{"type":"extras","doc":"You can also add variants to components with slots.\n\n```elixir\nimport TailwindVariants, only: [tv: 1, class_list: 2]\n\nalert = tv(%{\n  slots: %{\n    root: \"rounded py-3 px-5 mb-4\",\n    title: \"font-bold mb-1\",\n    message: \"\"\n  },\n  variants: %{\n    variant: %{\n      outlined: %{\n        root: \"border\"\n      },\n      filled: %{\n        root: \"\"\n      }\n    },\n    severity: %{\n      error: \"\",\n      success: \"\"\n    }\n  },\n  compound_variants: [\n    %{\n      variant: \"outlined\",\n      severity: \"error\",\n      class: %{\n        root: \"border-red-700 dark:border-red-500\",\n        title: \"text-red-700 dark:text-red-500\",\n        message: \"text-red-600 dark:text-red-500\"\n      }\n    },\n    %{\n      variant: \"outlined\",\n      severity: \"success\",\n      class: %{\n        root: \"border-green-700 dark:border-green-500\",\n        title: \"text-green-700 dark:text-green-500\",\n        message: \"text-green-600 dark:text-green-500\"\n      }\n    },\n    %{\n      variant: \"filled\",\n      severity: \"error\",\n      class: %{\n        root: \"bg-red-100 dark:bg-red-800\",\n        title: \"text-red-900 dark:text-red-50\",\n        message: \"text-red-700 dark:text-red-200\"\n      }\n    },\n    %{\n      variant: \"filled\",\n      severity: \"success\",\n      class: %{\n        root: \"bg-green-100 dark:bg-green-800\",\n        title: \"text-green-900 dark:text-green-50\",\n        message: \"text-green-700 dark:text-green-200\"\n      }\n    }\n  ],\n  default_variants: %{\n    variant: \"filled\",\n    severity: \"success\"\n  }\n})\n\n%{root: root, message: message, title: title} = class_list(alert, %{severity: \"error\", variant: \"outlined\"})\n\n# Use in Phoenix/LiveView\n \n   Oops, something went wrong \n   \n    Something went wrong saving your changes. Try again later.\n   \n \n```","title":"Variants with Slots - Tailwind Variants for Elixir","ref":"readme.html#variants-with-slots"},{"type":"extras","doc":"You can compose components using the `extend` parameter:\n\n```elixir\nimport TailwindVariants, only: [tv: 1, class_list: 2]\n\nbase_button = tv(%{\n  base: \"font-semibold dark:text-white py-1 px-3 rounded-full active:opacity-80 bg-zinc-100 hover:bg-zinc-200 dark:bg-zinc-800 dark:hover:bg-zinc-800\"\n})\n\nbuy_button = tv(%{\n  extend: base_button,\n  base: \"text-sm text-white rounded-lg shadow-lg uppercase tracking-wider bg-blue-500 hover:bg-blue-600 shadow-blue-500/50 dark:bg-blue-500 dark:hover:bg-blue-600\"\n})\n\n# Use in Phoenix/LiveView\n \n   Button \n   Buy button \n \n```","title":"Component Composition - Tailwind Variants for Elixir","ref":"readme.html#component-composition"},{"type":"extras","doc":"You can define styles that apply to specific slots when certain conditions are met:\n\n```elixir\nimport TailwindVariants, only: [tv: 1, class_list: 2]\n\nbutton = tv(%{\n  slots: %{\n    base: \"flex items-center\",\n    icon: \"w-4 h-4\",\n    text: \"ml-2\"\n  },\n  variants: %{\n    size: %{\n      sm: %{\n        icon: \"w-3 h-3\",\n        text: \"text-xs\"\n      },\n      lg: %{\n        icon: \"w-5 h-5\",\n        text: \"text-lg\"\n      }\n    }\n  },\n  compound_slots: [\n    %{\n      slots: [\"icon\", \"text\"],\n      size: \"lg\",\n      class: \"font-bold\" # This will apply to both icon and text slots when size is \"lg\"\n    }\n  ]\n})\n\n%{base: base, icon: icon, text: text} = class_list(button, %{size: \"lg\"})\n\n# Use in Phoenix/LiveView\n \n   <!-- SVG contents --> \n   Click me \n \n```","title":"Compound Slots - Tailwind Variants for Elixir","ref":"readme.html#compound-slots"},{"type":"extras","doc":"","title":"Configuration - Tailwind Variants for Elixir","ref":"readme.html#configuration"},{"type":"extras","doc":"If you need to customize the TwMerge behavior, you can pass a configuration in your component:\n\n```elixir\nbutton = tv(%{\n  base: \"...\",\n  config: %{\n    tw_merge: true, # Set to false to disable TwMerge and use simple joining\n  }\n})\n```","title":"TwMerge Configuration - Tailwind Variants for Elixir","ref":"readme.html#twmerge-configuration"},{"type":"extras","doc":"","title":"API Reference - Tailwind Variants for Elixir","ref":"readme.html#api-reference"},{"type":"extras","doc":"Creates a tailwind-variants component:\n\n```elixir\ntv(options)\n```\n\n#### Parameters\n\nThe `options` argument is a map with the following keys:\n\n- `base` (optional): The base styles for the component\n- `slots` (optional): A map of slot names to their styles\n- `variants` (optional): A map of variant names to their values\n- `default_variants` (optional): A map of variant names to their default values\n- `compound_variants` (optional): A list of compound variants\n- `compound_slots` (optional): A list of compound slots\n- `extend` (optional): Another component to extend\n- `config` (optional): Configuration options\n\n#### Return Value\n\nReturns a component that can be used with `class_list/2`.","title":"TailwindVariants.tv/1 - Tailwind Variants for Elixir","ref":"readme.html#tailwindvariants-tv-1"},{"type":"extras","doc":"Applies the component with the given props to generate class names:\n\n```elixir\nclass_list(component, props \\\\ %{})\n```\n\n#### Parameters\n\n- `component`: A component created with `tv/1`\n- `props`: A map of props to apply to the component\n\n#### Return Value\n\nReturns either:\n- A string of class names (if no slots are defined)\n- A map of slot functions (if slots are defined)","title":"TailwindVariants.class_list/2 - Tailwind Variants for Elixir","ref":"readme.html#tailwindvariants-class_list-2"},{"type":"extras","doc":"An alias for `class_list/2` for shorter code:\n\n```elixir\ntw(component, props \\\\ %{})\n```","title":"TailwindVariants.tw/2 - Tailwind Variants for Elixir","ref":"readme.html#tailwindvariants-tw-2"},{"type":"extras","doc":"Contributions are welcome! Please feel free to submit a Pull Request.","title":"Contributing - Tailwind Variants for Elixir","ref":"readme.html#contributing"},{"type":"extras","doc":"This project is licensed under the MIT License - see the LICENSE file for details.","title":"License - Tailwind Variants for Elixir","ref":"readme.html#license"},{"type":"extras","doc":"This library is an Elixir port of the JavaScript [tailwind-variants](https://www.tailwind-variants.org/) library created by Junior Garcia (@jrgarciadev) and Tianen Pang (@tianenpang).","title":"Acknowledgements - Tailwind Variants for Elixir","ref":"readme.html#acknowledgements"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}